mindroot.coreplugins package
============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   mindroot.coreplugins.admin
   mindroot.coreplugins.api_keys
   mindroot.coreplugins.chat
   mindroot.coreplugins.chat_avatar
   mindroot.coreplugins.check_list
   mindroot.coreplugins.credits
   mindroot.coreplugins.email
   mindroot.coreplugins.env_manager
   mindroot.coreplugins.events
   mindroot.coreplugins.index
   mindroot.coreplugins.jwt_auth
   mindroot.coreplugins.l8n
   mindroot.coreplugins.mcp_
   mindroot.coreplugins.persona
   mindroot.coreplugins.startup
   mindroot.coreplugins.subscriptions
   mindroot.coreplugins.usage
   mindroot.coreplugins.user_service

Module contents
---------------

.. automodule:: mindroot.coreplugins
   :members:
   :show-inheritance:
   :undoc-members:
